/*
** Module   : tty.js
** Abstract : java script terminal simulator.
**
** Copyright (c) 2014, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**         Golden Code Development Corporation
**                 CONFIDENTIAL
**
** -#- -I- --Date-- ----------------------Description--------------------------
** 001 MAG 20140110 First version.
** 002 MAG 20140204 Prevent back navigation.
**                  Disable browser context menu.
*/

/**
*  Initialize all JavaSscript submodules.
*  The order of initialization is mandatory:
*  tty.sound, tty.screen, tty.socket and tty.keyboard
*/
tty = (function()
{
   /* exports object */
   var my = {};
   
   /* OS detection */
   my.isWindows = navigator.appVersion.indexOf('Win') > -1;
   my.isMac = navigator.appVersion.indexOf('Mac') > -1;
   my.isUnix = navigator.appVersion.indexOf('X11') > -1;
   my.isLinux = navigator.appVersion.indexOf('Linux') > -1;
   
   /* browser detection */
   my.isFirefox = navigator.userAgent.toLowerCase().indexOf('firefox') > -1;       
   my.isChromium = navigator.userAgent.toLowerCase().indexOf('chromium') > -1;       
   my.isChrome = !!window.chrome;
   my.isIe = !!window.ActiveXObject;

   /* initialize modules */
   my.init = function(cfg)
   {  
      // prevent back navigation
      history.pushState({}, '', cfg.page);

      window.onpopstate = function(event) {
         if(event.type === 'popstate')
            history.pushState({}, '', cfg.page);
      };        
   
      // disable browser context menu
      document.oncontextmenu = function () 
      { 
         return false;
      };          
   
      tty.sound.init(cfg);
      tty.screen.init(cfg);
      tty.socket.init(cfg);
      tty.keyboard.init();
   };
   
   /* exports */
   return my;    
}());
