/*
** Module   : tty.sockets.js
** Abstract : WebSockets communication management.
**
** Copyright (c) 2014, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**         Golden Code Development Corporation
**                 CONFIDENTIAL
**
** -#- -I- --Date-- ----------------------Description--------------------------
** 001 MAG 20140110 First version.
** 002 MAG 20140204 Get attributes as a binary message.
**                  On quit command go back to login page. 
*/

tty.socket = (function()
{
   /* exports object */
   var my = {}; 

   /* web socket */
   var ws;

   /* connected */
   var connected = false;

   /* send data */
   my.send = function(data)
   {
      if (connected) 
      {
         ws.send(data);
      }
      else
      {
         tty.sound.beep();
      }
   };

   /* initialize module */
   my.init = function(cfg)
   {      
      if ('WebSocket' in window)
      {
         ws = new WebSocket(cfg.socket.url);

         // on web socket open
         ws.onopen = function()
         {
            connected = true;
            ws.binaryType = 'arraybuffer';
         };

         // on web socket message
         ws.onmessage = function(evt)
         {
            var data = evt.data;
            
            if (data instanceof ArrayBuffer)
            {
               // binary messages
               var message = new Uint8Array(data);
               
               // check for command id (0 = attributes)
               if (message[0] === 0)
               {
                  tty.screen.attr = message;
               }
            }
            else
            {
               // text messages
               var pay = JSON.parse(data);
               
               switch (pay.c)
               {
                  case 0:
                     // clear screen 
                     tty.screen.clear();                        
                     break;
                  case 1:
                     // write to screen 
                     tty.screen.type(pay.t);                        
                     break;
                  case 2:
                     // set cursor position
                     tty.screen.setCursorPosition(pay.x, pay.y);                        
                     break;
                  case 3:
                     // show cursor
                     tty.screen.setCursorStatus(true);                        
                     break;
                  case 4:
                     // hide cursor
                     tty.screen.setCursorStatus(false);                        
                     break;
                  case 5:
                     // message beep
                     tty.sound.beep();                        
                     break;
                  case 6:
                     // quit
                     window.location.replace(pay.u);                        
                     break;
               };
            }
         };

         // on web socket close
         ws.onclose = function()
         { 
            connected = false;
            tty.screen.error('Connection closed by remote host.'); 
         };
         
      } 
      else 
      {
         tty.screen.error('WebSocket NOT supported by your Browser.');
      }      
   };
   
   /* exports */
   return my;       
}());
    
